@@ -37,7 +37,7 @@ from .layout.dimension import LayoutDimension
 from .layout.lexers import PygmentsLexer
 from .layout.margins import PromptMargin, ConditionalMargin
 from .layout.menus import CompletionsMenu, MultiColumnCompletionsMenu
-from .layout.processors import PasswordProcessor, ConditionalProcessor, AppendAutoSuggestion, HighlightSearchProcessor, HighlightSelectionProcessor
+from .layout.processors import PasswordProcessor, ConditionalProcessor, AppendAutoSuggestion, HighlightSearchProcessor, HighlightSelectionProcessor, DisplayMultipleCursors
 from .layout.prompt import DefaultPrompt
 from .layout.screen import Char
 from .layout.toolbars import ValidationToolbar, SystemToolbar, ArgToolbar, SearchToolbar
@@ -96,13 +96,15 @@ def create_eventloop(inputhook=None, recognize_win32_paste=True):
         return Loop(inputhook=inputhook)
 
 
-def create_output(stdout=None, true_color=False):
+def create_output(stdout=None, true_color=False, ansi_colors_only=None):
     """
     Return an :class:`~prompt_toolkit.output.Output` instance for the command
     line.
 
     :param true_color: When True, use 24bit colors instead of 256 colors.
         (`bool` or :class:`~prompt_toolkit.filters.SimpleFilter`.)
+    :param ansi_colors_only: When True, restrict to 16 ANSI colors only.
+        (`bool` or :class:`~prompt_toolkit.filters.SimpleFilter`.)
     """
     stdout = stdout or sys.__stdout__
     true_color = to_simple_filter(true_color)
@@ -117,7 +119,9 @@ def create_output(stdout=None, true_color=False):
         if PY2:
             term = term.decode('utf-8')
 
-        return Vt100_Output.from_pty(stdout, true_color=true_color, term=term)
+        return Vt100_Output.from_pty(
+            stdout, true_color=true_color,
+            ansi_colors_only=ansi_colors_only, term=term)
 
 
 def create_asyncio_eventloop(loop=None):
@@ -256,7 +260,8 @@ def create_prompt_layout(message='', lexer=None, is_password=False,
             HasFocus(SEARCH_BUFFER)),
         HighlightSelectionProcessor(),
         ConditionalProcessor(AppendAutoSuggestion(), HasFocus(DEFAULT_BUFFER) & ~IsDone()),
-        ConditionalProcessor(PasswordProcessor(), is_password)
+        ConditionalProcessor(PasswordProcessor(), is_password),
+        DisplayMultipleCursors(DEFAULT_BUFFER),
     ]
 
     if extra_input_processors:
@@ -288,7 +293,7 @@ def create_prompt_layout(message='', lexer=None, is_password=False,
             # Reserve the space, either when there are completions, or when
             # `complete_while_typing` is true and we expect completions very
             # soon.
-            if buff.complete_while_typing(cli) or buff.complete_state is not None:
+            if buff.complete_while_typing() or buff.complete_state is not None:
                 return LayoutDimension(min=reserve_space_for_menu)
 
         return LayoutDimension()
@@ -403,10 +408,10 @@ def create_prompt_application(
     :param editing_mode: ``EditingMode.VI`` or ``EditingMode.EMACS``.
     :param vi_mode: `bool`, if True, Identical to ``editing_mode=EditingMode.VI``.
     :param complete_while_typing: `bool` or
-        :class:`~prompt_toolkit.filters.CLIFilter`. Enable autocompletion while
-        typing.
+        :class:`~prompt_toolkit.filters.SimpleFilter`. Enable autocompletion
+        while typing.
     :param enable_history_search: `bool` or
-        :class:`~prompt_toolkit.filters.CLIFilter`. Enable up-arrow parting
+        :class:`~prompt_toolkit.filters.SimpleFilter`. Enable up-arrow parting
         string matching.
     :param lexer: :class:`~prompt_toolkit.layout.lexers.Lexer` to be used for
         the syntax highlighting.
@@ -594,16 +599,20 @@ def run_application(
         exec_context = {'patch_context': patch_context, 'cli': cli,
                         'Document': Document}
         exec_(textwrap.dedent('''
-        import asyncio
-
-        @asyncio.coroutine
         def prompt_coro():
-            with patch_context:
-                result = yield from cli.run_async(reset_current_buffer=False)
+            # Inline import, because it slows down startup when asyncio is not
+            # needed.
+            import asyncio
 
-            if isinstance(result, Document):  # Backwards-compatibility.
-                return result.text
-            return result
+            @asyncio.coroutine
+            def run():
+                with patch_context:
+                    result = yield from cli.run_async(reset_current_buffer=False)
+
+                if isinstance(result, Document):  # Backwards-compatibility.
+                    return result.text
+                return result
+            return run()
         '''), exec_context)
 
         return exec_context['prompt_coro']()
@@ -688,9 +697,19 @@ def print_tokens(tokens, style=None, true_color=False):
     renderer_print_tokens(output, tokens, style)
 
 
+def clear():
+    """
+    Clear the screen.
+    """
+    out = create_output()
+    out.erase_screen()
+    out.cursor_goto(0, 0)
+    out.flush()
+
+
 # Deprecated alias for `prompt`.
 get_input = prompt
-# Deprecated alias for create_default_layout
+# Deprecated alias for create_prompt_layout
 create_default_layout = create_prompt_layout
-# Deprecated alias for create_default_application
+# Deprecated alias for create_prompt_application
 create_default_application = create_prompt_application
